"""
This program will allow you to be notified of Github new releases
"""

__all__ = ['parser', 'webhook', 'notifier']
__version__ = '0.3.0'
